@@ -1,11 +1,11 @@
 package Koha::Contrib::Tamil::Authority::Task;
 {
-  $Koha::Contrib::Tamil::Authority::Task::VERSION = '0.014';
+  $Koha::Contrib::Tamil::Authority::Task::VERSION = '0.015';
 }
 # ABSTRACT: Base class for managing authorities manipulations
 use Moose;
 
-extends 'Koha::Contrib::Tamil::FileProcess';
+extends 'AnyEvent::Processor';
 
 use 5.010;
 use utf8;
@@ -44,7 +44,7 @@ Koha::Contrib::Tamil::Authority::Task - Base class for managing authorities mani
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 AUTHOR
 
