@@ -1,17 +1,20 @@
 package Koha::Contrib::Tamil::Indexer;
 {
-  $Koha::Contrib::Tamil::Indexer::VERSION = '0.014';
+  $Koha::Contrib::Tamil::Indexer::VERSION = '0.015';
 }
 # ABSTRACT: Class doing Zebra Koha indexing
 
 use Moose;
 
+use 5.010;
+use utf8;
 use Carp;
 use Koha::Contrib::Tamil::Koha;
 use Koha::Contrib::Tamil::RecordReader;
 use Koha::Contrib::Tamil::RecordWriter::File::Marcxml;
-use Koha::Contrib::Tamil::Conversion;
+use AnyEvent::Processor::Conversion;
 use File::Path;
+use IO::File;
 use Locale::TextDomain 'Koha-Contrib-Tamil';
 
 
@@ -94,7 +97,7 @@ sub run {
 
     # STEP 1.1: Records to update
     print __"Exporting records to update", "\n" if $self->verbose;
-    my $exporter = Koha::Contrib::Tamil::Conversion->new(
+    my $exporter = AnyEvent::Processor::Conversion->new(
         reader => Koha::Contrib::Tamil::RecordReader->new(
             koha   => $self->koha,
             source => $self->source,
@@ -102,9 +105,7 @@ sub run {
             xml    => '1'
         ),
         writer => Koha::Contrib::Tamil::RecordWriter::File::Marcxml->new(
-            file    => "$from_dir/update/records",
-            binmode => 'utf8'
-        ),
+            fh => IO::File->new( "$from_dir/update/records", '>:utf8' ) ),
         blocking    => $self->blocking,
         verbose     => $self->verbose,
     );
@@ -113,7 +114,7 @@ sub run {
     # STEP 1.2: Record to delete, if zebraqueue
     if ( ! $is_full_indexing ) {
         print __"Exporting records to delete", "\n" if $self->verbose;
-        $exporter = Koha::Contrib::Tamil::Conversion->new(
+        $exporter = AnyEvent::Processor::Conversion->new(
             reader => Koha::Contrib::Tamil::RecordReader->new(
                 koha   => $self->koha,
                 source => $self->source,
@@ -121,9 +122,7 @@ sub run {
                 xml    => '1'
             ),
             writer => Koha::Contrib::Tamil::RecordWriter::File::Marcxml->new(
-                file    => "$from_dir/delete/records",
-                binmode => 'utf8'
-            ),
+                fh => IO::File->new( "$from_dir/delete/records", '>:utf8' ) ),
             blocking    => $self->blocking,
             verbose     => $self->verbose,
         );
@@ -184,7 +183,7 @@ Koha::Contrib::Tamil::Indexer - Class doing Zebra Koha indexing
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 METHODS
 
